ChatManager class
- Inheritance
-
- Object
- ChangeNotifier
- BaseNotifier
- ChatManager
- Available extensions
Constructors
- ChatManager(Room room)
- ChatManager.of(String roomId)
-
factory
Properties
-
availableInputtedLinks
↔ Set<
String> -
getter/setter pair
-
connection
→ Future<
bool> -
finalinherited
-
connectivity
→ Stream<
bool> -
finalinherited
- connectivityDebounce → Duration
-
Debounces rapid connectivity flaps (Wi-Fi transitions, tower hopping).
Without this, every flicker would tear down + restart all subscriptions.
no setterinherited
-
deletedNotifier
→ ValueNotifier<
bool> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- hasMoreMessages → bool
-
no setter
- isActive → bool
-
no setterinherited
- isAttached → bool
-
no setter
- isConnected → bool
-
no setterinherited
- isDeleted → bool
-
no setter
- isEmpty → bool
-
no setter
- isLoadingMore → bool
-
no setter
- isLoggedIn → bool
-
no setterinherited
- isPaused → bool
-
no setterinherited
- isRunning → bool
-
no setterinherited
- isStarted → bool
-
no setterinherited
- loading ↔ bool
-
getter/setter pair
-
mappedMessages
↔ Map<
String, Message> -
getter/setter pair
- me → String
-
no setteroverride
-
messages
→ List<
Message> -
no setter
- pageSize ↔ int
-
Page size for paginated message loading. Override via constructor or
at the RoomManager level if app needs different sizes.
getter/setter pair
- pausedDurationWhenAppBackground → Duration
-
finalinherited
-
pins
→ List<
Message> -
no setter
- profile → Profile
-
no setter
-
profileNotifier
→ ValueNotifier<
Profile> -
latefinal
- replyMsg ↔ Message?
-
getter/setter pair
- room ↔ Room
-
getter/setter pair
- roomId → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sortedMessages
→ List<
Message> -
no setter
- status → Status
-
no setter
-
statusNotifier
→ ValueNotifier<
Status> -
latefinal
-
typings
→ List<
Typing> -
no setter
-
typingsNotifier
→ ValueNotifier<
List< Typing> > -
latefinal
-
unseens
→ List<
Message> -
no setter
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
attach(
String uid, {bool? connected}) → void -
inherited
-
background(
) → void -
override
-
connect(
) → void -
connected(
) → void -
inherited
-
delete(
Message msg) → Future< void> -
Available on ChatManager, provided by the ChatManagerActions extension
-
deleteForMe(
Message msg) → Future< void> -
Available on ChatManager, provided by the ChatManagerActions extension
-
deletePermanently(
Message msg) → Future< void> -
Available on ChatManager, provided by the ChatManagerActions extension
-
deletes(
List< Message> messages) → Future<void> -
Available on ChatManager, provided by the ChatManagerActions extension
-
deletesForMe(
Iterable< Message> messages) → Future<void> -
Available on ChatManager, provided by the ChatManagerActions extension
-
detach(
) → void -
inherited
-
didChangeAccessibilityFeatures(
) → void -
Called when the system changes the set of currently active accessibility
features.
inherited
-
didChangeAppLifecycleState(
AppLifecycleState state) → void -
Called when the system puts the app in the background or returns
the app to the foreground.
inherited
-
didChangeLocales(
List< Locale> ? locales) → void -
Called when the system tells the app that the user's locale has
changed. For example, if the user changes the system language
settings.
inherited
-
didChangeMetrics(
) → void -
Called when the application's dimensions change. For example,
when a phone is rotated.
inherited
-
didChangePlatformBrightness(
) → void -
Called when the platform brightness changes.
inherited
-
didChangeTextScaleFactor(
) → void -
Called when the platform's text scale factor changes.
inherited
-
didChangeViewFocus(
ViewFocusEvent event) → void -
Called whenever the PlatformDispatcher receives a notification that the
focus state on a view has changed.
inherited
-
didHaveMemoryPressure(
) → void -
Called when the system is running low on memory.
inherited
-
didPopRoute(
) → Future< bool> -
Called when the system tells the app to pop the current route, such as
after a system back button press or back gesture.
inherited
-
didPushRoute(
String route) → Future< bool> -
Called when the host tells the application to push a new route onto the
navigator.
inherited
-
didPushRouteInformation(
RouteInformation routeInformation) → Future< bool> -
Called when the host tells the application to push a new
RouteInformation and a restoration state onto the router.
inherited
-
didRequestAppExit(
) → Future< AppExitResponse> -
Called when a request is received from the system to exit the application.
inherited
-
disconnect(
) → void -
disconnected(
) → void -
inherited
-
dismissLink(
String link) → void -
dispose(
) → void -
Discards any resources used by the object.
override
-
edit(
Message msg, String content) → Future< void> -
Available on ChatManager, provided by the ChatManagerMessaging extension
-
foreground(
) → void -
override
-
forward(
List< String> targetRoomIds, Message msg) → Future<void> -
Available on ChatManager, provided by the ChatManagerMessaging extension
-
handleCancelBackGesture(
) → void -
Called when a predictive back gesture is canceled, indicating that no
navigation should occur.
inherited
-
handleCommitBackGesture(
) → void -
Called when a predictive back gesture is finished successfully, indicating
that the current route should be popped.
inherited
-
handleStartBackGesture(
PredictiveBackEvent backEvent) → bool -
Called at the start of a predictive back gesture.
inherited
-
handleStatusBarTap(
) → void -
Called when the user taps the status bar on iOS, to scroll a scroll
view to the top.
inherited
-
handleUpdateBackGestureProgress(
PredictiveBackEvent backEvent) → void -
Called when a predictive back gesture moves.
inherited
-
inputtedLinks(
String text) → void -
invisible(
Message msg) → void -
Available on ChatManager, provided by the ChatManagerStatus extension
-
loadMoreMessages(
) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notify(
) → void -
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
onRoomDeleted(
) → void -
paused(
) → void -
override
-
pin(
Message msg) → Future< void> -
Available on ChatManager, provided by the ChatManagerActions extension
-
pop(
Message message) → void -
pops(
Iterable< Message> messages) → void -
put(
Message message) → void -
puts(
Iterable< Message> messages) → void -
react(
Message msg, String? react, {ChatSilentNotification? notification}) → Future< void> -
Available on ChatManager, provided by the ChatManagerActions extension
-
remove(
Message msg) → Future< void> -
Available on ChatManager, provided by the ChatManagerActions extension
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
reply(
Message? message) → void -
run(
) → void -
override
-
seen(
Message msg) → Future< void> -
Available on ChatManager, provided by the ChatManagerStatus extension
-
send(
Message message, {ChatSilentNotification? notification, VerifyToSendMessage? verifyToSend, OnDeniedToSendMessage? onDeniedToSend}) → Future< void> -
Available on ChatManager, provided by the ChatManagerMessaging extension
-
stop(
) → void -
override
-
togglePin(
Message msg) → Future< void> -
Available on ChatManager, provided by the ChatManagerActions extension
-
toString(
) → String -
A string representation of this object.
inherited
-
typing(
bool status) → Future< void> -
Available on ChatManager, provided by the ChatManagerStatus extension
-
unpin(
Message msg) → Future< void> -
Available on ChatManager, provided by the ChatManagerActions extension
-
update(
String msgId, Map< String, dynamic> changes) → Future<void> -
Available on ChatManager, provided by the ChatManagerMessaging extension
-
verified(
) → void -
visible(
Message msg) → void -
Available on ChatManager, provided by the ChatManagerStatus extension
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
ofOrNull(
String roomId) → ChatManager?