RoomManagerBase class abstract

Inheritance
Implementers

Constructors

RoomManagerBase({required Duration pausedDurationWhenAppBackground, required Future<bool> connection, required Stream<bool> connectivity})

Properties

activeParticipants Set<String>
getter/setter pair
aiDelegate ChatAiDelegate
no setter
botEnabled bool
no setter
cacheDelegate ChatCacheDelegate
no setter
canOperate bool
no setter
connection Future<bool>
finalinherited
connectivity Stream<bool>
finalinherited
connectivityDebounce Duration
Debounces rapid connectivity flaps (Wi-Fi transitions, tower hopping). Without this, every flicker would tear down + restart all subscriptions.
no setterinherited
error bool
getter/setter pair
errorReporter ChatErrorReporter
no setter
fetchGroupUserProfiles bool
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isActive bool
no setterinherited
isConnected bool
no setterinherited
isLoggedIn bool
no setterinherited
isPaused bool
no setterinherited
isRunning bool
no setterinherited
isStarted bool
no setterinherited
loading bool
getter/setter pair
mappedProfiles Map<String, Profile>
getter/setter pair
mappedRooms Map<String, Room>
getter/setter pair
mappedStatuses Map<String, Status>
getter/setter pair
mappedTypings Map<String, Typing>
getter/setter pair
maxCachedManagers int
no setter
me String
no setterinherited
messageDelegate ChatMessageDelegate
no setter
modelConfigs ChatModelConfigs
no setter
n ChatFieldValueNormalizer
no setter
notificationDelegate ChatNotificationDelegate
no setter
pausedDurationWhenAppBackground Duration
finalinherited
preloadInboxMetadataCount int
no setter
profileDelegate ChatProfileDelegate
no setter
roomDelegate ChatRoomDelegate
no setter
rooms List<Room>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settingsDelegate ChatUserSettingsDelegate
no setter
statusDelegate ChatStatusDelegate
no setter
syncTokenEnabled bool
no setter
typingDelegate ChatTypingDelegate
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
attach(String uid, {bool? connected}) → void
inherited
background() → void
inherited
botProfileFromRoom(Room? room) BotProfile
buildActiveParticipants() Set<String>
cacheProfile(Profile profile) → void
cancelMetadataIfOrphaned(String uid) → void
cleanupOrphanedParticipants(Room room) → void
connected() → void
inherited
createMessageByBot(Message msg) Future<void>
detach() → void
inherited
didChangeAccessibilityFeatures() → void
Called when the system changes the set of currently active accessibility features.
inherited
didChangeAppLifecycleState(AppLifecycleState state) → void
Called when the system puts the app in the background or returns the app to the foreground.
inherited
didChangeLocales(List<Locale>? locales) → void
Called when the system tells the app that the user's locale has changed. For example, if the user changes the system language settings.
inherited
didChangeMetrics() → void
Called when the application's dimensions change. For example, when a phone is rotated.
inherited
didChangePlatformBrightness() → void
Called when the platform brightness changes.
inherited
didChangeTextScaleFactor() → void
Called when the platform's text scale factor changes.
inherited
didChangeViewFocus(ViewFocusEvent event) → void
Called whenever the PlatformDispatcher receives a notification that the focus state on a view has changed.
inherited
didHaveMemoryPressure() → void
Called when the system is running low on memory.
inherited
didPopRoute() Future<bool>
Called when the system tells the app to pop the current route, such as after a system back button press or back gesture.
inherited
didPushRoute(String route) Future<bool>
Called when the host tells the application to push a new route onto the navigator.
inherited
didPushRouteInformation(RouteInformation routeInformation) Future<bool>
Called when the host tells the application to push a new RouteInformation and a restoration state onto the router.
inherited
didRequestAppExit() Future<AppExitResponse>
Called when a request is received from the system to exit the application.
inherited
disconnected() → void
inherited
dispose() → void
Discards any resources used by the object.
inherited
disposeAllManagers() → void
disposeAllRoomNotifiers() → void
disposeRoomNotifier(String roomId) → void
disposeSubscriptions() → void
ensureMetadataForRoom(Room room) → void
ensureMetadataListener(String uid) → void
extractFriend(List<String> participants) String?
foreground() → void
inherited
handleBotReply(String roomId, List<Message> messages) Future<void>
handleCancelBackGesture() → void
Called when a predictive back gesture is canceled, indicating that no navigation should occur.
inherited
handleCommitBackGesture() → void
Called when a predictive back gesture is finished successfully, indicating that the current route should be popped.
inherited
handleStartBackGesture(PredictiveBackEvent backEvent) bool
Called at the start of a predictive back gesture.
inherited
handleStatusBarTap() → void
Called when the user taps the status bar on iOS, to scroll a scroll view to the top.
inherited
handleUpdateBackGestureProgress(PredictiveBackEvent backEvent) → void
Called when a predictive back gesture moves.
inherited
isParticipantInAnyRoom(String uid) bool
isRoomActive(String roomId) bool
isRoomCreated(String roomId) bool
isRoomManaged(String roomId) bool
isTyping(Room? room) bool
managerForRoom(Room room) ChatManager
managerOrNull(String roomId) ChatManager?
markDeliveredForRoom(String roomId) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notify() → void
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
notifyManagerRoomDeleted(String roomId) → void
participantsOf(Room room) Set<String>
paused() → void
inherited
pop(String roomId) → void
profileFor(String? uid) Profile
profileForBot(String? uid) BotProfile
profileForUser(String? uid) UserProfile
profileFromRoom(Room? room) Profile
pushNotification({required String roomId, required String msgId, required ChatNotification notification}) Future<void>
put(Room room) → void
reconcileMetadata(Set<String> newActives) → void
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
room(String? roomId) Room
roomNotifier(String roomId) ValueNotifier<Room>
run() → void
inherited
sendNotification(Message msg, ChatSilentNotification notification) Future<void>
sortedParticipants(List<String> participants) List<String>
startListening() → void
startMeProfileListener() → void
statusFor(String? uid) Status
statusFromRoom(Room? room) Status
stop() → void
inherited
timestamp(Object? raw) ChatValueTimestamp
toString() String
A string representation of this object.
inherited
typingFor(String? uid) Typing
typingsFromRoom(Room? room) List<Typing>
update(String roomId, Map<String, dynamic> value) Future<bool>
updateAllRoomNotifiers() → void
updateMessage(String roomId, String msgId, Map<String, dynamic> value, {Map<String, dynamic> roomValues = const {}}) Future<bool>
updateNotifiersForParticipant(String uid) → void
updateRoomNotifier(String roomId) → void
userProfileFromRoom(Room? room) UserProfile

Operators

operator ==(Object other) bool
The equality operator.
inherited