ChatAiImageReplyRequest class
- Inheritance
-
- Object
- ChatAiRequest
- ChatAiReplyRequest
- ChatAiImageReplyRequest
Constructors
-
ChatAiImageReplyRequest({required BotProfile profile, required List<
Message> conversations, required Message? replyMessage, required List<String> urls, required String? caption}) -
const
Properties
- caption → String?
-
final
-
conversations
→ List<
Message> -
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- profile → BotProfile
-
finalinherited
- replyMessage → Message?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
urls
→ List<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited