ChatErrorReporter class abstract
Pluggable error reporter. App provides an implementation (Crashlytics, Sentry, custom logger) and chat layer routes all caught exceptions to it instead of swallowing them silently.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
report(
Object error, {StackTrace? stackTrace, String? source, Map< String, Object?> ? context}) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited