PaginatedMessageStream class abstract

A message stream with pagination control.

Constructors

PaginatedMessageStream()

Properties

hashCode int
The hash code for this object.
no setterinherited
hasMore bool
Whether more older messages are available.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream Stream<List<Message>>
Live stream of the current loaded window.
no setter

Methods

cancel() Future<void>
Cancel and clean up.
loadMore() Future<bool>
Load the next page of older messages. Returns true if more were loaded, false if already at the start of history.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited