ChatNotificationContent class
Constructors
Properties
- body → String
-
final
- expiresAt → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- isExpired → bool
-
no setter
- isValid → bool
-
no setter
- platform → String
-
final
- profile → Profile?
-
final
- retryCount → int
-
final
- roomId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
final
- token → String
-
final
Methods
-
copyWith(
{int? retryCount}) → ChatNotificationContent -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited