ChatNotificationDelegate class abstract

Constructors

ChatNotificationDelegate()

Properties

hashCode int
The hash code for this object.
no setterinherited
onTokenRefresh Stream<String?>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteToken() Future<void>
fetchToken() Future<String?>
isTokenValid(String? token) Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendNotification(ChatNotificationContent content) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited