ChatRoomDelegate class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
create(
String roomId, Map< String, dynamic> value) → Future<void> -
delete(
String roomId) → Future< void> -
get(
String roomId) → Future< Room> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
stream(
String uid) → Stream< List< Room> > -
toString(
) → String -
A string representation of this object.
inherited
-
update(
String roomId, Map< String, dynamic> value) → Future<void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited