ChatValueTimestamp class

Inheritance

Properties

hashCode int
The hash code for this object.
no setteroverride
isEmpty bool
no setter
normalized DateTime
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
no setter
timestampOrNull DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

parse(Object? source) ChatValueTimestamp
tryParse(Object? source) ChatValueTimestamp?