offlineQueueEnabled property
Whether the offline queue is enabled. App can override to disable in builds where queueing is undesirable.
Implementation
bool get offlineQueueEnabled => true;
Whether the offline queue is enabled. App can override to disable in builds where queueing is undesirable.
bool get offlineQueueEnabled => true;