MessageKeys class

Constructors

MessageKeys({String id = 'id', String roomId = 'roomId', String senderId = 'senderId', String content = 'content', String data = 'data', String kind = 'kind', String type = 'type', String statuses = 'statuses', String createdAt = 'createdAt', String updatedAt = 'updatedAt', String urls = 'urls', String url = 'url', String waveform = 'waveform', String replyId = 'replyId', String reactions = 'reactions', String pins = 'pins', String durationInSec = 'durationInSec', String thumbnail = 'thumbnail', String deletes = 'deletes', String removes = 'removes', String isDeleted = 'isDeleted', String isEdited = 'isEdited', String editedAt = 'editedAt', String isForwarded = 'isForwarded', String extra = 'extra'})
const

Properties

content String
final
createdAt String
final
data String
final
deletes String
final
durationInSec String
final
editedAt String
final
extra String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
isDeleted String
final
isEdited String
final
isForwarded String
final
kind String
final
pins String
final
reactions String
final
removes String
final
replyId String
final
roomId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
senderId String
final
statuses String
final
thumbnail String
final
type String
final
updatedAt String
final
url String
final
urls String
final
waveform String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

i MessageKeys
no setter