TextMessage class
Constructors
- TextMessage.create(String text, {String? roomId, MessageExtra? extra, String? id, String? senderId, String? replyId, ChatValueTimestamp? createdAt})
-
factory
- TextMessage.empty()
-
const
- TextMessage.from(Message msg, String text)
-
factory
Properties
- content → String?
-
no setterinherited
- createdAt → ChatValueTimestamp
-
finalinherited
-
deletes
→ Map<
String, bool> -
finalinherited
- editedAt → ChatValueTimestamp
-
finalinherited
- extra → MessageExtra
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
finalinherited
- isDeleted → bool
-
finalinherited
- isDeletedByMe → bool
-
no setterinherited
- isDeliveredByMe → bool
-
no setterinherited
- isEditable → bool
-
no setterinherited
- isEdited → bool
-
finalinherited
- isEmpty → bool
-
no setterinherited
- isForwarded → bool
-
finalinherited
- isPinned → bool
-
no setterinherited
- isReactedByMe → bool
-
no setterinherited
- isRemovedByMe → bool
-
no setterinherited
- isRetrying → bool
-
no setterinherited
- isSeenByMe → bool
-
no setterinherited
- isSending → bool
-
no setterinherited
- isSentByMe → bool
-
no setterinherited
- me → String
-
no setterinherited
-
pins
→ Map<
String, bool> -
finalinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setteroverride
- reactByMe → String?
-
no setterinherited
-
reactions
→ Map<
String, String> -
finalinherited
-
removes
→ Map<
String, bool> -
finalinherited
- replyId → String
-
finalinherited
- replyMessage → Message
-
no setterinherited
- roomId → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- senderId → String
-
finalinherited
- shouldRemove → bool
-
no setterinherited
- source → MessageExtra
-
no setteroverride
- status → MessageStatus
-
no setterinherited
-
statuses
→ Map<
String, MessageStatus> -
finalinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - text → String
-
final
- type → MessageType
-
finalinherited
- updatedAt → ChatValueTimestamp
-
finalinherited
Methods
-
copyWith(
{bool? isDeleted, bool? isDeletedForMe, bool? isEdited, bool? isForwarded, bool? isPinned, bool? isRemoved, bool clearReplyId = false, String? id, String? roomId, String? senderId, String? replyId, String? react, ChatValueTimestamp? createdAt, ChatValueTimestamp? editedAt, ChatValueTimestamp? updatedAt, MessageStatus? status, MessageExtra? extra, String? text}) → TextMessage -
override
-
findPathOrUrls(
[bool thumbnail = false]) → List< String> -
inherited
-
isDelivered(
Set< String> participants) → bool -
inherited
-
isSeen(
Set< String> participants) → bool -
inherited
-
lastMessage(
{bool edited = false, bool deleted = false}) → String -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notificationBody(
String? sender) → String -
inherited
-
resolveWith(
Map changes) → TextMessage -
override
-
statusFor(
String uid) → MessageStatus -
inherited
-
toString(
) → String - A string representation of this object.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited