BotProfile class

Inheritance

Constructors

BotProfile({required String id, required String name, String? photo, ProfileExtra extra = const {}, required int age, required String gender, required String country, required String continent, required String speakingStyle, required List<String> languages, required List<String> interests, required List<String> personalityTraits, required List<String> favoriteTopics})
const
BotProfile.empty()
const
BotProfile.parse(Object? source, {ProfileExtra? extra})
factory

Properties

age int
final
continent String
final
country String
final
extra ProfileExtra
finalinherited
favoriteTopics List<String>
final
gender String
final
hashCode int
The hash code for this object.
no setterinherited
id String
finalinherited
interests List<String>
final
isBot bool
no setterinherited
isEmpty bool
no setteroverride
languages List<String>
final
name String
no setteroverride
nameSymbol String?
no setterinherited
personalityTraits List<String>
final
photo String?
finalinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source ProfileExtra
no setter
speakingStyle String
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

copyWith({String? id, String? name, String? photo, int? age, String? gender, String? country, String? continent, String? speakingStyle, List<String>? languages, List<String>? interests, List<String>? personalityTraits, List<String>? favoriteTopics, ProfileExtra? extra}) BotProfile
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited