BotProfileKeys class

Constructors

BotProfileKeys({String id = 'profile_id', String name = 'display_name', String photo = 'display_photo', String age = 'age', String gender = 'gender', String country = 'country', String continent = 'continent', String speakingStyle = 'speakingStyle', String languages = 'languages', String interests = 'interests', String personalityTraits = 'personalityTraits', String favoriteTopics = 'favoriteTopics', String extra = 'profile_extra'})
const

Properties

age String
final
continent String
final
country String
final
extra String
final
favoriteTopics String
final
gender String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
interests String
final
languages String
final
name String
final
personalityTraits String
final
photo String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speakingStyle String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

i BotProfileKeys
no setter