Profile class

Implementers

Constructors

Profile({required String id, String? name, String? photo, ProfileExtra extra = const {}})
const
Profile.empty()
const

Properties

extra ProfileExtra
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
isBot bool
no setter
isEmpty bool
no setter
name String?
final
nameSymbol String?
no setter
photo String?
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited