UserProfile class
Constructors
- UserProfile({required String id, String? name, String? photo, ProfileExtra extra = const {}, required String platform, required String token, String? room, bool newMessageAlerts = false, bool newRoomAlerts = false})
-
const
- UserProfile.empty()
-
const
- UserProfile.parse(Object? source, {ProfileExtra? extra})
-
factory
Properties
- extra → ProfileExtra
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
finalinherited
- isBot → bool
-
no setterinherited
- isEmpty → bool
-
no setterinherited
- name → String?
-
finalinherited
- nameSymbol → String?
-
no setterinherited
- newMessageAlerts → bool
-
final
- newRoomAlerts → bool
-
final
- photo → String?
-
finalinherited
- platform → String
-
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setteroverride
- room → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → ProfileExtra
-
no setter
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - token → String
-
final
Methods
-
copyWith(
{String? id, String? name, String? photo, String? platform, String? token, String? room, bool clearRoom = false, bool? newMessageAlerts, bool? newRoomAlerts, ProfileExtra? extra}) → UserProfile -
isActiveRoom(
String roomId) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited