DirectRoom class

Inheritance

Constructors

DirectRoom({Set<String> archives = const {}, Set<String> blocks = const {}, ChatValueTimestamp createdAt = const ChatValueTimestamp(), String createdBy = '', RoomExtra extra = const {}, String id = '', bool isBot = false, bool isDeleted = false, bool isLocal = false, bool isVerified = false, String? lastMessage, bool lastMessageDeleted = false, String lastMessageId = '', String lastMessageSenderId = '', Map<String, MessageStatus> lastMessageStatuses = const {}, Set<String> leaves = const {}, Set<String> mutes = const {}, Set<String> participants = const {}, Set<String> pins = const {}, Map<String, String> removes = const {}, Set<String> restricts = const {}, Map<String, int> unseenCounts = const {}, ChatValueTimestamp updatedAt = const ChatValueTimestamp()})
const
DirectRoom.empty()
const
DirectRoom.from(Room room)
factory

Properties

archives Set<String>
finalinherited
blocks Set<String>
finalinherited
createdAt ChatValueTimestamp
finalinherited
createdBy String
finalinherited
extra RoomExtra
finalinherited
friendId String
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
finalinherited
isAdminByMe bool
no setterinherited
isArchivedByMe bool
no setterinherited
isBlockedByMe bool
no setterinherited
isBot bool
finalinherited
isDeleted bool
finalinherited
isEmpty bool
no setterinherited
isGroup bool
finalinherited
isLeaveByMe bool
no setterinherited
isLocal bool
finalinherited
isMutedByMe bool
no setterinherited
isPinnedByMe bool
no setterinherited
isRemovedByMe bool
no setterinherited
isRestrictedByMe bool
no setterinherited
isSentByMe bool
no setterinherited
isVerified bool
finalinherited
lastMessage String?
finalinherited
lastMessageDeleted bool
finalinherited
lastMessageId String
finalinherited
lastMessageSenderId String
finalinherited
lastMessageStatus String?
no setterinherited
lastMessageStatuses Map<String, MessageStatus>
finalinherited
leaves Set<String>
finalinherited
me String
no setterinherited
mutes Set<String>
finalinherited
participants Set<String>
finalinherited
pins Set<String>
finalinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
removes Map<String, String>
finalinherited
restricts Set<String>
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source RoomExtra
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
unseenCount int
no setterinherited
unseenCounts Map<String, int>
no setterinherited
updatedAt ChatValueTimestamp
finalinherited

Methods

copyWith({Iterable<String>? blocks, ChatValueTimestamp? createdAt, String? createdBy, RoomExtra? extra, String? id, bool? isAddMember, bool? isArchived, bool? isBlocked, bool? isBot, bool? isDeleted, bool? isGroup, bool? isLeaved, bool? isLocal, bool? isMuted, bool? isPinned, bool? isRemoved, bool? isRestricted, bool? isVerified, bool clearLastMessage = false, String? lastMessage, bool? lastMessageDeleted, String? lastMessageId, String? lastMessageSenderId, Map<String, MessageStatus>? lastMessageStatuses, Iterable<String>? participants, Iterable<String>? restricts, Map<String, int>? unseenCounts, ChatValueTimestamp? updatedAt}) DirectRoom
override
formattedLastMessage({String? sender, bool isTyping = false, String formatter(String key, String value)?}) String
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited