Room class

Implementers

Constructors

Room({Set<String> archives = const {}, Set<String> blocks = const {}, ChatValueTimestamp createdAt = const ChatValueTimestamp(), String createdBy = '', RoomExtra extra = const {}, String id = '', bool isBot = false, bool isDeleted = false, bool isGroup = false, bool isLocal = false, bool isVerified = false, String? lastMessage, bool lastMessageDeleted = false, String lastMessageId = '', String lastMessageSenderId = '', Map<String, MessageStatus> lastMessageStatuses = const {}, Set<String> leaves = const {}, Set<String> mutes = const {}, Set<String> participants = const {}, Set<String> pins = const {}, Map<String, String> removes = const {}, Set<String> restricts = const {}, ChatValueTimestamp updatedAt = const ChatValueTimestamp(), Map<String, int> unseenCounts = const {}})
const
Room.empty()
const
Room.parse(Object? source, {RoomExtra? extra})
factory

Properties

archives Set<String>
final
blocks Set<String>
final
createdAt ChatValueTimestamp
final
createdBy String
final
extra RoomExtra
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
isAdminByMe bool
no setter
isArchivedByMe bool
no setter
isBlockedByMe bool
no setter
isBot bool
final
isDeleted bool
final
isEmpty bool
no setter
isGroup bool
final
isLeaveByMe bool
no setter
isLocal bool
final
isMutedByMe bool
no setter
isPinnedByMe bool
no setter
isRemovedByMe bool
no setter
isRestrictedByMe bool
no setter
isSentByMe bool
no setter
isVerified bool
final
lastMessage String?
final
lastMessageDeleted bool
final
lastMessageId String
final
lastMessageSenderId String
final
lastMessageStatus String?
no setter
lastMessageStatuses Map<String, MessageStatus>
final
leaves Set<String>
final
me String
no setter
mutes Set<String>
final
participants Set<String>
final
pins Set<String>
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
removes Map<String, String>
final
restricts Set<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source RoomExtra
no setter
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
unseenCount int
no setter
unseenCounts Map<String, int>
no setter
updatedAt ChatValueTimestamp
final

Methods

copyWith({Iterable<String>? blocks, ChatValueTimestamp? createdAt, String? createdBy, RoomExtra? extra, String? id, bool? isAddMember, bool? isArchived, bool? isBlocked, bool? isBot, bool? isDeleted, bool? isGroup, bool? isLeaved, bool? isLocal, bool? isMuted, bool? isPinned, bool? isRemoved, bool? isRestricted, bool? isVerified, bool clearLastMessage = false, String? lastMessage, bool? lastMessageDeleted, String? lastMessageId, String? lastMessageSenderId, Map<String, MessageStatus>? lastMessageStatuses, Iterable<String>? participants, Iterable<String>? restricts, Map<String, int>? unseenCounts, ChatValueTimestamp? updatedAt}) Room
formattedLastMessage({String? sender, bool isTyping = false, String formatter(String key, String value)?}) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited