StatusKeys class

Constructors

StatusKeys({String isOnline = 'isOnline', String lastSeen = 'lastSeen'})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isOnline String
final
lastSeen String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

i StatusKeys
no setter