Typing class

Constructors

Typing({required String id, required String roomId})
const
Typing.empty()
const
Typing.parse(Object? source)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
isEmpty bool
no setter
profile Profile
no setter
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
roomId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited