TypingKeys class

Constructors

TypingKeys({String id = 'id', String roomId = 'roomId'})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
roomId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

i TypingKeys
no setter