ChatModelConfigs class

Constructors

ChatModelConfigs({MessageKeys messageKeys = const MessageKeys(), BotProfileKeys botProfileKeys = const BotProfileKeys(), UserProfileKeys userProfileKeys = const UserProfileKeys(), RoomKeys roomKeys = const RoomKeys(), StatusKeys statusKeys = const StatusKeys(), TypingKeys typingKeys = const TypingKeys()})
const

Properties

botProfileKeys BotProfileKeys
final
hashCode int
The hash code for this object.
no setterinherited
messageKeys MessageKeys
final
roomKeys RoomKeys
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusKeys StatusKeys
final
typingKeys TypingKeys
final
userProfileKeys UserProfileKeys
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited