ChatAppbarData class

Constructors

ChatAppbarData({required bool isDeleted, required Profile profile, required Status status, required List<Typing> typings})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isDeleted bool
final
isTyping bool
no setter
profile Profile
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status Status
final
typings List<Typing>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited