Properties
hashCode
→ int
The hash code for this object.
no setter inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
Methods
create (String roomId , String msgId , Map <String , dynamic > value )
→ Future <void >
delete (String roomId , String id )
→ Future <void >
deleteAll (String roomId )
→ Future <void >
deleteFromStorage (String url )
→ Future <void >
deletes (Iterable <Message > messages )
→ Future <void >
fetch (String roomId )
→ Future <List <Message > >
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
stream (String roomId )
→ Stream <List <Message > >
streamPaginated (String roomId , {int pageSize = 50 })
→ PaginatedMessageStream
Paginated stream — emits the latest limit messages, with the ability
to load older pages on demand. App's delegate implementation (Firestore,
Supabase, etc.) is responsible for the actual pagination logic.
toString ()
→ String
A string representation of this object.
inherited
update (String roomId , String id , Map <String , dynamic > value )
→ Future <void >
updates (String roomId , Map <String , Map <String , dynamic > > values )
→ Future <void >
upload (MessageUploadData data )
→ Future <String >