ChatFieldValueNormalizer class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
message(
Object? raw) → Object? -
normalize(
Object? raw, Object? normalizer(Object? raw)?) → Map< String, dynamic> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
profile(
Object? raw) → Object? -
room(
Object? raw) → Object? -
status(
Object? raw) → Object? -
timestamp(
Object? raw) → ChatValueTimestamp -
toString(
) → String -
A string representation of this object.
inherited
-
typing(
Object? raw) → Object?
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited