Message class
- Implementers
Constructors
-
Message({required String id, required String roomId, required String senderId, required ChatValueTimestamp createdAt, required ChatValueTimestamp updatedAt, required MessageType type, required Map<
String, MessageStatus> statuses, required Map<String, bool> deletes, required Map<String, bool> pins, required Map<String, bool> removes, required Map<String, String> reactions, required bool isDeleted, required bool isEdited, required bool isForwarded, required MessageExtra extra, required ChatValueTimestamp? editedAt, required String? replyId}) -
const
- Message.empty()
-
const
- Message.parse(Object? source, {MessageExtra? extra})
-
factory
Properties
- content → String?
-
no setter
- createdAt → ChatValueTimestamp
-
final
-
deletes
→ Map<
String, bool> -
final
- editedAt → ChatValueTimestamp
-
final
- extra → MessageExtra
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- isDeleted → bool
-
final
- isDeletedByMe → bool
-
no setter
- isDeliveredByMe → bool
-
no setter
- isEditable → bool
-
no setter
- isEdited → bool
-
final
- isEmpty → bool
-
no setter
- isForwarded → bool
-
final
- isPinned → bool
-
no setter
- isReactedByMe → bool
-
no setter
- isRemovedByMe → bool
-
no setter
- isRetrying → bool
-
no setter
- isSeenByMe → bool
-
no setter
- isSending → bool
-
no setter
- isSentByMe → bool
-
no setter
- me → String
-
no setter
-
pins
→ Map<
String, bool> -
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- reactByMe → String?
-
no setter
-
reactions
→ Map<
String, String> -
final
-
removes
→ Map<
String, bool> -
final
- replyId → String
-
final
- replyMessage → Message
-
no setter
- roomId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- senderId → String
-
final
- shouldRemove → bool
-
no setter
- source → MessageExtra
-
no setter
- status → MessageStatus
-
no setter
-
statuses
→ Map<
String, MessageStatus> -
final
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - type → MessageType
-
final
- updatedAt → ChatValueTimestamp
-
final
Methods
-
copyWith(
{bool? isDeleted, bool? isDeletedForMe, bool? isEdited, bool? isForwarded, bool? isPinned, bool? isRemoved, bool clearReplyId = false, String? id, String? roomId, String? senderId, String? replyId, String? react, ChatValueTimestamp? createdAt, ChatValueTimestamp? editedAt, ChatValueTimestamp? updatedAt, MessageStatus? status, MessageExtra? extra}) → Message -
findPathOrUrls(
[bool thumbnail = false]) → List< String> -
isDelivered(
Set< String> participants) → bool -
isSeen(
Set< String> participants) → bool -
lastMessage(
{bool edited = false, bool deleted = false}) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notificationBody(
String? sender) → String -
resolveWith(
Map changes) → Message -
statusFor(
String uid) → MessageStatus -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited