UserProfileKeys class
Constructors
- UserProfileKeys({String id = 'profile_id', String name = 'display_name', String photo = 'display_photo', String platform = 'platform', String token = 'device_token', String room = 'active_room', String extra = 'profile_extra', String newMessageAlerts = 'new_message_alerts', String newRoomAlerts = 'new_room_alerts'})
-
const
Properties
- extra → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- name → String
-
final
- newMessageAlerts → String
-
final
- newRoomAlerts → String
-
final
- photo → String
-
final
- platform → String
-
final
- room → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- token → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- i → UserProfileKeys
-
no setter