Status class
Constructors
- Status({required bool isOnline, required ChatValueTimestamp lastSeen})
-
const
- Status.empty()
-
const
- Status.parse(Object? source)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isOnline → bool
-
final
- lastSeen → ChatValueTimestamp
-
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
source
→ Map<
String, dynamic> -
no setter
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited